@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 __title__ = 'metzoo-python-reader'
-__version__ = '0.0.6'
-__build__ = 0x000006
+__version__ = '0.0.11'
+__build__ = 0x00000B
 __author__ = 'Edrans S.A.'
 __copyright__ = 'Copyright 2016 Edrans S.A.'
 
